## Issue Type
- Refactor

## Motivation
-

## Scope / Boundaries
- In scope:
- Out of scope:

## Current Pain Points
-

## Target Design
-

## Risk Assessment
- Compatibility risk:
- Performance risk:
- Migration risk:

## Equivalence Validation Plan
- [ ] Baseline tests/snapshots prepared
- [ ] Behavior parity verified

## Sub-issues
- [ ] #<id> <title>
- [ ] #<id> <title>
